@@ -158,7 +158,8 @@ sub configure {
 sub build {
     my ($self) = @_;
 
-    build_recipe();
+    my $parallel = ($self->get_parallel() > 0) ? $self->get_parallel() : 0;
+    build_recipe(parallel => $parallel);
     if (!$dh{DOARCH}) {
         haddock_recipe();
     }
